@@ -120,6 +120,18 @@ sub _getType {
 
     my $result;
 
+    if (canRun('/sbin/sysctl')) {
+        my $handle = getFileHandle(
+            command => '/sbin/sysctl -n security.jail.jailed',
+            logger => $logger
+        );
+        my $line = <$handle>;
+        if ($line && $line =~ /1/) {
+             return 'BSDJail';
+        }
+        close $handle;
+    }
+
     # loaded modules
 
     if (-f '/proc/modules') {
@@ -140,24 +152,24 @@ sub _getType {
 
     # dmesg
 
+    my $handle;
     if (-r '/var/log/dmesg') {
         my $handle = getFileHandle(file => '/var/log/dmesg', logger => $logger);
-        $result = _matchPatterns($handle);
-        close $handle;
     } elsif (-x '/bin/dmesg') {
         my $handle = getFileHandle(command => '/bin/dmesg', logger => $logger);
-        $result = _matchPatterns($handle);
-        close $handle;
     } elsif (-x '/sbin/dmesg') {
         # On OpenBSD, dmesg is in sbin
         # http://forge.fusioninventory.org/issues/402
         my $handle = getFileHandle(command => '/sbin/dmesg', logger => $logger);
-        $result = _matchPatterns($handle);
-        close $handle;
     }
-    return $result if $result;
 
-    # scsci
+    if ($handle) {
+        my $result = _matchPatterns($handle);
+        close $handle;
+        return $result if $result;
+    }
+
+    # scsi
 
     if (-f '/proc/scsi/scsi') {
         my $handle = getFileHandle(
@@ -169,6 +181,13 @@ sub _getType {
     }
     return $result if $result;
 
+    if (getFirstMatch(
+        file    => '/proc/1/environ',
+        pattern => qr/container=lxc/
+    )) {
+        return 'LXC';
+    }
+
     # OpenVZ
     if (-f '/proc/self/status') {
         my $handle = getFileHandle(
